pub struct AgentServiceCheck {Show 24 fields
pub CheckID: Option<String>,
pub Name: Option<String>,
pub Args: Option<Vec<String>>,
pub DockerContainerID: Option<String>,
pub Shell: Option<String>,
pub Interval: Option<String>,
pub Timeout: Option<String>,
pub TTL: Option<String>,
pub HTTP: Option<String>,
pub Header: Option<HashMap<String, String>>,
pub Method: Option<String>,
pub Body: Option<String>,
pub TCP: Option<String>,
pub Status: Option<String>,
pub Notes: Option<String>,
pub TLSServerName: Option<String>,
pub TLSSkipVerify: Option<bool>,
pub GRPC: Option<String>,
pub GRPCUseTLS: Option<bool>,
pub AliasNode: Option<String>,
pub AliasService: Option<String>,
pub SuccessBeforePassing: Option<i64>,
pub FailuresBeforeCritical: Option<i64>,
pub DeregisterCriticalServiceAfter: Option<String>,
}Expand description
AgentServiceCheck is used to define a node or service level check
Fields
CheckID: Option<String>Name: Option<String>Args: Option<Vec<String>>DockerContainerID: Option<String>Shell: Option<String>Only supported for Docker.
Interval: Option<String>Timeout: Option<String>TTL: Option<String>HTTP: Option<String>Header: Option<HashMap<String, String>>Method: Option<String>Body: Option<String>TCP: Option<String>Status: Option<String>Notes: Option<String>TLSServerName: Option<String>TLSSkipVerify: Option<bool>GRPC: Option<String>GRPCUseTLS: Option<bool>AliasNode: Option<String>AliasService: Option<String>SuccessBeforePassing: Option<i64>FailuresBeforeCritical: Option<i64>DeregisterCriticalServiceAfter: Option<String>In Consul 0.7 and later, checks that are associated with a service may also contain this optional DeregisterCriticalServiceAfter field, which is a timeout in the same Go time format as Interval and TTL. If a check is in the critical state for more than this configured value, then its associated service (and all of its associated checks) will automatically be deregistered.