Struct consul_rs::agent::SampledValue [−][src]
pub struct SampledValue {
pub Name: Option<String>,
pub Count: Option<i64>,
pub Sum: Option<f64>,
pub Min: Option<f64>,
pub Max: Option<f64>,
pub Mean: Option<f64>,
pub Stddev: Option<f64>,
pub Labels: Option<HashMap<String, String>>,
}Expand description
SampledValue stores info about a metric that is incremented over time, such as the number of requests to an HTTP endpoint.
Fields
Name: Option<String>Count: Option<i64>Sum: Option<f64>Min: Option<f64>Max: Option<f64>Mean: Option<f64>Stddev: Option<f64>Labels: Option<HashMap<String, String>>Trait Implementations
Returns the “default value” for a type. Read more
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more