pub struct ServiceRegisterOpts {
pub ReplaceExistingChecks: bool,
}Expand description
ServiceRegisterOpts is used to pass extra options to the service register.
Fields
ReplaceExistingChecks: boolMissing healthchecks will be deleted from the agent. Using this parameter allows to idempotently register a service and its checks without having to manually deregister checks.