ConsulConfig

Struct ConsulConfig 

pub struct ConsulConfig {
    pub config: Option<Config>,
    pub watch_services: Option<Vec<WatchService>>,
}

Fields

config: Option<Config>watch_services: Option<Vec<WatchService>>

Implementations

Source

impl ConsulConfig

pub async fn load_config(path: &str) -> Result<()>

pub async fn new_request(&self, method: Method, path: &str) -> Result<Request>

pub async fn service_register( &self, service: &AgentServiceRegistration, ) -> Result<StatusCode>

service_register is used to register a new service with the local agent

use consul_rs::api::CONSUL_CONFIG;
use async_std::task::block_on;
use consul_rs::agent::AgentServiceRegistration;
let clone_consul = CONSUL_CONFIG.clone();
let consul = block_on(clone_consul.read());
let mut service = AgentServiceRegistration::default();
service.ID = Some(String::from("321"));
service.Name = Some(String::from("test"));
service.Port = Some(8080);
service.Address = Some(String::from("127.0.0.1"));
let s = block_on(consul.service_register(&service)).unwrap();
println!("{}", s);
pub async fn service_register_opts( &self, service: &AgentServiceRegistration, opts: &ServiceRegisterOpts, ) -> Result<StatusCode>

pub async fn service_register_self( &self, service: &AgentServiceRegistration, opts: &ServiceRegisterOpts, ) -> Result<StatusCode>

pub async fn service_deregister(&self, service_id: String) -> Result<StatusCode>

service_deregister is used to register a new service with the local agent

use consul_rs::api::CONSUL_CONFIG;
use async_std::task::block_on;
use consul_rs::ConsulTrait;
use consul_rs::agent::AgentServiceRegistration;
let clone_consul = CONSUL_CONFIG.clone();
let consul = block_on(clone_consul.read());
let service_id = String::from("321");
let s = block_on(consul.service_deregister(service_id)).unwrap();
println!("{}", s);
pub async fn watch_services() -> Result<()>

pub async fn random_policy( &self, service_name: &str, tag: &str, ) -> Result<String>