Struct consul_rs::config_entry::ExposeConfig [−][src]
pub struct ExposeConfig {
pub Checks: Option<bool>,
pub Paths: Option<Vec<ExposePath>>,
}Expand description
ExposeConfig describes HTTP paths to expose through Envoy outside of Connect. Users can expose individual paths and/or all HTTP/GRPC paths for checks.
Fields
Checks: Option<bool>Checks defines whether paths associated with Consul checks will be exposed. This flag triggers exposing all HTTP and GRPC check paths registered for the service.
Paths: Option<Vec<ExposePath>>Paths is the list of paths exposed through the proxy.