Struct consul_rs::config_entry::ExposePath [−][src]
pub struct ExposePath {
pub ListenerPort: Option<usize>,
pub Path: Option<String>,
pub LocalPathPort: Option<usize>,
pub Protocol: Option<String>,
pub ParsedFromCheck: Option<bool>,
}Fields
ListenerPort: Option<usize>ListenerPort defines the port of the proxy’s listener for exposed paths.
Path: Option<String>Path is the path to expose through the proxy, ie. “/metrics.”
LocalPathPort: Option<usize>LocalPathPort is the port that the service is listening on for the given path.
Protocol: Option<String>Protocol describes the upstream’s service protocol. Valid values are “http” and “http2”, defaults to “http”
ParsedFromCheck: Option<bool>ParsedFromCheck is set if this path was parsed from a registered check