Struct consul_rs::api::TLSConfig [−][src]
pub struct TLSConfig {
pub address: Option<String>,
pub ca_file: Option<String>,
pub ca_path: Option<String>,
pub ca_pem: Option<String>,
pub cert_file: Option<String>,
pub cert_pem: Option<String>,
pub key_file: Option<String>,
pub key_pem: Option<String>,
pub insecure_skip_verify: Option<bool>,
}Expand description
TLSConfig is used to generate a TLSClientConfig that’s useful for talking to Consul using TLS.
Fields
address: Option<String>Address is the optional address of the Consul server. The port, if any will be removed from here and this will be set to the ServerName of the resulting config.
ca_file: Option<String>CAFile is the optional path to the CA certificate used for Consul communication, defaults to the system bundle if not specified.
ca_path: Option<String>CAPath is the optional path to a directory of CA certificates to use for Consul communication, defaults to the system bundle if not specified.
ca_pem: Option<String>CAPem is the optional PEM-encoded CA certificate used for Consul communication, defaults to the system bundle if not specified.
cert_file: Option<String>CertFile is the optional path to the certificate for Consul communication. If this is set then you need to also set KeyFile.
cert_pem: Option<String>CertPEM is the optional PEM-encoded certificate for Consul communication. If this is set then you need to also set KeyPEM.
key_file: Option<String>KeyFile is the optional path to the private key for Consul communication. If this is set then you need to also set CertFile.
key_pem: Option<String>KeyPEM is the optional PEM-encoded private key for Consul communication. If this is set then you need to also set CertPEM.
insecure_skip_verify: Option<bool>InsecureSkipVerify if set to true will disable TLS host verification.